@@ -8,6 +8,8 @@
 
 #include "OverlayWidget.h"
 #include "SoundPlayer.h"
+#include "LEDBlinker.h"
+#include "UserDefaults.h"
 
 #include "arm_neon.h"
 
@@ -63,6 +65,11 @@ void CameraThread::run() {
     SoundPlayer soundPlayer;
     SoundPlayer::SoundAction exposureStartSound(&soundPlayer);
     
+    printf("Making LED blinker device...\n");
+    // Make a device that blinks the front LED when a picture is taken
+    LEDBlinker blinker;
+    LEDBlinker::BlinkAction blink(&blinker);
+
     printf("Entering main loop...\n");
     while (keepGoing) {
         // deal with FCam events
@@ -114,6 +121,13 @@ void CameraThread::run() {
             case FCam::Event::ShutterReleased:
                 emit shutterReleased();
                 fullDepress = false;
+                break;
+            case FCam::Event::N900LensClosed:
+                emit lensCoverClosed();
+                break;
+            case FCam::Event::N900LensOpened:
+                emit lensCoverOpened();
+                break;                
             };
         }
     
@@ -152,7 +166,12 @@ void CameraThread::run() {
                                                 (shots-1));
                     hdrPhoto[i].frameTime = 200000;
                     hdrPhoto[i].clearActions();
-                    hdrPhoto[i].addAction(exposureStartSound);
+                    if (UserDefaults::instance()["captureSound"].asInt()) {
+                        hdrPhoto[i].addAction(exposureStartSound);                    
+                    }
+                    if (UserDefaults::instance()["captureBlink"].asInt()) {
+                        hdrPhoto[i].addAction(blink);                    
+                    }                    
                 }
                 sensor.capture(hdrPhoto);
                 takeSnapshot = false;
@@ -166,7 +185,12 @@ void CameraThread::run() {
                 
                 // Make a camera sound at the start of the exposure
                 photo.clearActions();
-                photo.addAction(exposureStartSound);
+                if (UserDefaults::instance()["captureSound"].asInt()) {
+                    photo.addAction(exposureStartSound);
+                }
+                if (UserDefaults::instance()["captureBlink"].asInt()) {
+                    photo.addAction(blink);
+                }
                 
                 if (parameters.burst.mode == CameraParameters::Burst::SINGLE) {
                     photo.id = SINGLE;
@@ -197,6 +221,9 @@ void CameraThread::run() {
             }
         }
 
+        
+        bool imageSaved = false;
+        bool imageSavedWasBurst = false;
         // Drain the frame queue
         do {
             // Do anything that must be done with the returned frame
@@ -214,6 +241,8 @@ void CameraThread::run() {
                 }
                 
                 emit newImage(new ImageItem(frame));
+                imageSaved = true;
+                imageSavedWasBurst = frame.shot().id != SINGLE;
                 break;
             case SHARPEST: {
                 // evaluate the sharpness of this frame
@@ -242,9 +271,10 @@ void CameraThread::run() {
                 // Save the best one in the burst
                 if (luckyCount == 7) {
                     emit newImage(new ImageItem(sharpest));
+                    imageSaved = true;                    
                     sharpest = FCam::Frame();
                 }
-
+        
                 luckyCount++;
                 break;
             }
@@ -281,7 +311,9 @@ void CameraThread::run() {
                 printf("Got back a frame with unknown id: %d\n", frame.shot().id);
             }
         } while (sensor.framesPending());
-
+        // Display the animation for the frame capture (box moving from viewfinder down to review screen)
+        if (imageSaved) emit captureComplete(imageSavedWasBurst);
+        
         // Now do any optional, CPU-intensive things with the returned frame
         switch (frame.shot().id) {
         case VIEWFINDER:
@@ -444,8 +476,15 @@ void CameraThread::updateState(const FCam::Frame &frame) {
             } else {
                 parameters.gain.value = viewfinder.gain;
             }
+        }            
+
+        // clamp to possible exposures
+        if (parameters.exposure.value > 1.0f) {
+            parameters.exposure.value = 1.0f;
+            viewfinder.exposure = 1000000;
         }
 
+
     } else {
 
         viewfinder.exposure = int(1000000*parameters.exposure.value+0.5);
@@ -490,3 +529,13 @@ void CameraThread::updateState(const FCam::Frame &frame) {
 
     parameters.notify();
 }
+
+bool CameraThread::lensCovered() {
+    FILE * file = fopen("/sys/devices/platform/gpio-switch/cam_shutter/state", "r");
+    char state = fgetc(file); // file contains either "open" or "closed"
+    fclose(file);
+    return state == 'c';
+}
+
+
+
