@@ -35,7 +35,8 @@ class CameraThread : public QThread {
     // The requested state of the camera. Fiddle with this object to
     // change the behavior of the camera 
     CameraParameters parameters;
-    
+    // Static utility function that tests whether the lens cover is currently shut.
+    static bool lensCovered();
   public slots:
 
     // Shut down the camera thread. 
@@ -49,9 +50,15 @@ class CameraThread : public QThread {
         exitLock.unlock();
     }
     
+    void pause() {
+        sensor.stopStreaming();
+    }
   signals:
      // A photograph was taken 
     void newImage(ImageItem *);
+    
+    // A capture sequence has completed
+    void captureComplete(bool isBurst);
 
     // A new viewfinder frame arrived 
     void viewfinderFrame(FCam::Frame);
@@ -62,6 +69,8 @@ class CameraThread : public QThread {
     void shutterPressed();
     void shutterReleased();
 
+    void lensCoverClosed();
+    void lensCoverOpened();
 
     // An irrecoverable error has occured.
     // Connect something that will display an error message to the user.
@@ -122,4 +131,6 @@ class CameraThread : public QThread {
     QMutex exitLock;
 };
 
+
+
 #endif
