@@ -4,12 +4,15 @@
 LEDBlinker::LEDBlinker() {
     /* Set up the LED flasher (see http://wiki.maemo.org/LED_patterns) */
     FILE *f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_mode", "w");
-    fwrite("load", 5, 1, f);
+    if (!f) return;
+    fwrite("load\n", 5, 1, f);
     fclose(f);
     f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_leds", "w");
-    fwrite("000011100", 9, 1, f);
+    if (!f) return;
+    fwrite("000011100\n", 10, 1, f);
     fclose(f);
     f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_load", "w");
+    if (!f) return;
     fwrite("9d80" // refresh engine
            "40ff" // set max brightness
            "1100" // pause for a little bit
@@ -17,15 +20,23 @@ LEDBlinker::LEDBlinker() {
            "c000" // terminate pattern
            "c000"
            "c000"
-           "c000",
+           "c000\n",
            33, 1, f);
     fclose(f);
 }
 
+LEDBlinker::~LEDBlinker() {
+    FILE *f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_mode", "w");
+    if (!f) return;
+    fwrite("disabled\n", 9, 1, f);
+    fclose(f);        
+}
+
 void LEDBlinker::blink() {
     // Flash the device LED
-        FILE *f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_mode", "w");
-        fwrite("run", 4, 1, f);
+    FILE *f = fopen("/sys/class/i2c-adapter/i2c-2/2-0032/engine3_mode", "w");
+    if (!f) return;
+    fwrite("run\n", 4, 1, f);
     fclose(f);
 }
 
