@@ -74,6 +74,12 @@ OverlayWidget::OverlayWidget(QWidget *par) : QWidget(par)  {
     if (ioctl(overlay_fd, OMAPFB_GET_COLOR_KEY, &old_color_key)){
         perror("OMAPFB_GET_COLOR_KEY");
     }
+    /*
+    printf("old color key trans key = %x\n", old_color_key.trans_key);
+    printf("old color key background = %x\n", old_color_key.background);
+    printf("old color key key type = %x\n", old_color_key.key_type);
+    printf("old color key channel out = %x\n", old_color_key.channel_out);
+    */
     // Set up the color key
     struct omapfb_color_key color_key;
     color_key.key_type = OMAPFB_COLOR_KEY_GFX_DST;
@@ -117,6 +123,11 @@ void OverlayWidget::moveEvent(QMoveEvent *) {
 
 
 OverlayWidget::~OverlayWidget() {
+    old_color_key.trans_key = 0x842;
+    old_color_key.background = 0x0;
+    old_color_key.key_type = OMAPFB_COLOR_KEY_GFX_DST;
+    old_color_key.channel_out = OMAPFB_CHANNEL_OUT_LCD;
+    
     if (ioctl(overlay_fd, OMAPFB_SET_COLOR_KEY, &old_color_key)) {
         perror("OMAPFB_SET_COLOR_KEY");
     }
